/**
 * CInputPhoneCode - 表单项，手机验证码输入框
 * @author Tevin
 */

<template>
    <view class="c-input-phone-code">
        <AtInput
            :name="itemRes.name"
            :title="itemRes.label"
            type="text"
            :placeholder="placeholder"
            :required="itemRes.required"
            :error="itemRes.error"
            :value="itemRes.formData[itemRes.name]"
            :onChange="evt=>itemRes.onChange(evt)"
        >
            <AtButton
                class="c-input-phone-btn"
                type="primary"
                size="small"
                :disabled="holding"
                :onClick="evt=>handleClick()"
            >{{btnText}}</AtButton>
        </AtInput>
    </view>
</template>

<script>
import { AtInput, AtButton } from 'taro-ui-vue';
import './cInputPhoneCode.scss';

export default {
    name: 'CInputPhoneCode',
    components: {
        AtInput,
        AtButton,
    },
    props: {
        // 表单数据资源（表单组件内部机制专用）
        itemRes: Object,
        // 占位提示
        placeholder: String,
        // 验证码计时器开始方式
        //   true 点击按钮后立即自动开始
        //   false 后台返回为成功时才开始
        autoStart: {
            type: Boolean,
            default: true,
        },
        // 发送请求，通知后端给手机发验证码
        onCallPhoneCode: Function,
        // 刷新cd后，通知父组件更新图片地址
        onRefreshCD: {
            type: Function,
            default: () => () => null,
        },
    },
    data() {
        return {
            cd: 60,
            holding: false,
            timer: null,
        };
    },
    computed: {
        btnText() {
            if (this.holding) {
                return this.cd + '秒后重新获取';
            } else {
                return '重新获取验证码';
            }
        },
    },
    methods: {
        handleClick() {
            if (this.holding) {
                return;
            }
            const startCD = () => {
                this.holding = true;
                this.cd = 60;
                clearInterval(this.timer);
                this.timer = setInterval(() => {
                    this.cd -= 1;
                    if (this.cd === 0) {
                        this.holding = false;
                        this.cd = 60;
                        this.onRefreshCD(true);
                    }
                }, 1000);
            };
            if (this.autoStart) {
                startCD();
                this.onCallPhoneCode(() => null);
            } else {
                this.onCallPhoneCode(() => {
                    startCD();
                });
            }
        },
        // 重置holding
        $resetHolding() {
            this.holding = false;
        },
    },
};
</script>